form/field_registry library

Classes

FieldRegistry
The form half of rendering: one widget per writable field, given the current value, a change callback, an error slot and an enabled flag as one FieldState.

Typedefs

FieldBuilder = Widget Function(BuildContext context, SchemaComponent component, FieldState state)