CardLeading class

Constructors

CardLeading({required String type, required String field, String? fallback})
const
CardLeading.fromJson(Map<String, dynamic> json, String path)
factory

Properties

fallback String?
What to show when the field is empty, e.g. initials.
final
field String
final
hashCode int
The hash code for this object.
no setterinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
type String
image or icon.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited