PollConfig class

Optional background-revalidation cadence published by the panel.

A malformed declaration reads as absent: polling is an additive freshness capability, never a reason to reject an otherwise usable panel document.

Constructors

PollConfig({required Duration lists, required Duration detail, required Duration dashboard})
const

Properties

dashboard Duration
final
detail Duration
final
hashCode int
The hash code for this object.
no setterinherited
lists Duration
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Object? value) PollConfig?