RealtimeConfig class

Public Reverb connection settings published by the panel.

Parsing is deliberately lenient: malformed realtime configuration disables push and leaves polling available rather than rejecting the panel schema.

Constructors

RealtimeConfig({required String key, required String host, required int port, required String scheme, required String authEndpoint})
const

Properties

authEndpoint String
final
hashCode int
The hash code for this object.
no setterinherited
host String
final
key String
final
port int
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scheme String
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Object? value) RealtimeConfig?