ResourceBadge class

The web sidebar's count badge for one resource — the value is whatever string the panel renders (usually a count), the colour the same semantic vocabulary card badges use (success, warning, …).

Constructors

ResourceBadge({required String value, String? color})
const
ResourceBadge.fromJson(Map<String, dynamic> json)
factory

Properties

color String?
final
hashCode int
The hash code for this object.
no setterinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited