channel property
Private resource change-feed channel. Its presence means the resource opted into realtime for this authorized schema; null keeps polling.
Implementation
final String? channel;
Private resource change-feed channel. Its presence means the resource opted into realtime for this authorized schema; null keeps polling.
final String? channel;