live property
When true, a change to this field triggers a /state round-trip so the
server can re-evaluate the schema.
Implementation
final bool live;
When true, a change to this field triggers a /state round-trip so the
server can re-evaluate the schema.
final bool live;