SelectOption class

One choice in a SelectComponent. value stays untyped because the contract allows ints (foreign keys) and strings (enums) alike.

Constructors

SelectOption({required Object value, required String label})
const
SelectOption.fromJson(Map<String, dynamic> json, String path)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
label → String
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
value → Object
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited