optionsFor method
The options last fetched for field, empty until one arrives.
Implementation
List<SelectOption> optionsFor(String field) =>
_optionsPages[field]?.options ?? const [];
The options last fetched for field, empty until one arrives.
List<SelectOption> optionsFor(String field) =>
_optionsPages[field]?.options ?? const [];