ui/component_direction library

Functions

buildWithComponentDirection(BuildContext context, ComponentDirection? direction, WidgetBuilder builder) Widget
Builds a node under its explicit direction, or directly under context when the node inherits the panel direction.