FilamentFormFactor enum

Window size classes for Material 3 adaptive layout.

Defines the form factors for responsive UI based on viewport width. See Material 3 documentation on window size classes: https://m3.material.io/foundations/adaptive-design/large-screens/overview

Inheritance
Available extensions

Values

compact → const FilamentFormFactor

Compact form factor for narrow viewports (< 600dp). Typically phones in portrait orientation.

medium → const FilamentFormFactor

Medium form factor for medium-width viewports (600dp – 839dp). Typically tablets in portrait, or phones in landscape.

expanded → const FilamentFormFactor

Expanded form factor for wide viewports (≥ 840dp). Typically tablets in landscape or desktop.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FilamentFormFactor>
A constant List of the values in this enum, in order of their declaration.