registry property
Null builds EntryRegistry.defaults with onLinkTap and a related-
record tap that opens the target record in the current pane.
Implementation
final EntryRegistry? registry;
Null builds EntryRegistry.defaults with onLinkTap and a related-
record tap that opens the target record in the current pane.
final EntryRegistry? registry;