maxContentWidth property
Maximum width for the form content. Null uses a default based on the current layout (720 when not compact, unconstrained when compact).
Implementation
final double? maxContentWidth;
Maximum width for the form content. Null uses a default based on the current layout (720 when not compact, unconstrained when compact).
final double? maxContentWidth;