widgetRegistry property
Application-owned widgets inserted around the fields and save action.
Implementation
final FilamentWidgetRegistry? widgetRegistry;
Application-owned widgets inserted around the fields and save action.
final FilamentWidgetRegistry? widgetRegistry;