DashboardWidgetScope class final

Inheritance

Constructors

DashboardWidgetScope({required DashboardProvider provider, int? index, DashboardWidgetData? dashboardWidget})
const

Properties

dashboardWidget DashboardWidgetData?
final
hashCode int
The hash code for this object.
no setterinherited
index int?
Set for FilamentWidgetSlot.dashboardBeforeWidget and FilamentWidgetSlot.dashboardAfterWidget.
final
provider DashboardProvider
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited