FilamentWidgetSlot enum

Stable locations where an application can insert its own Flutter widgets.

Slots are deliberately semantic rather than pixel coordinates. This keeps an application's extensions in the intended place when the package adapts a screen between phone, tablet, desktop, LTR, and RTL layouts.

Inheritance
Available extensions

Values

panelIndexBeforeContent → const FilamentWidgetSlot
panelIndexAfterContent → const FilamentWidgetSlot
dashboardBeforeContent → const FilamentWidgetSlot
dashboardBeforeWidget → const FilamentWidgetSlot
dashboardAfterWidget → const FilamentWidgetSlot
dashboardAfterContent → const FilamentWidgetSlot
resourceListBeforeContent → const FilamentWidgetSlot
resourceListAfterContent → const FilamentWidgetSlot
resourceViewBeforeContent → const FilamentWidgetSlot
resourceViewBeforeRelations → const FilamentWidgetSlot
resourceViewAfterContent → const FilamentWidgetSlot
resourceFormBeforeFields → const FilamentWidgetSlot
resourceFormAfterFields → const FilamentWidgetSlot
resourceFormBeforeActions → const FilamentWidgetSlot
resourceFormAfterActions → const FilamentWidgetSlot
relationListBeforeContent → const FilamentWidgetSlot
relationListAfterContent → const FilamentWidgetSlot

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FilamentWidgetSlot>
A constant List of the values in this enum, in order of their declaration.