ResourceLabels class
Display strings for a resource. Already localised by Laravel — the client uses them verbatim.
Constructors
- ResourceLabels({required String singular, required String plural, String? icon})
-
const
-
ResourceLabels.fromJson(Map<
String, dynamic> json, String path) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → String?
-
final
- plural → String
-
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- singular → String
-
final
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited