MapPointValue class final
One geographic point. Numeric strings are accepted because the upstream Filament plugin documents and stores that shape; the mobile client always exposes numbers and sends numbers back.
Constructors
- MapPointValue({required double lat, required double lng})
-
const
- MapPointValue.fromJson(Object? value, String path)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- lat → double
-
final
- lng → double
-
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, double> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited