FilamentBreakpoints class

Breakpoints for determining the active FilamentFormFactor.

Defines the viewport width thresholds where the form factor transitions. Boundaries are inclusive on the upper class: width 600 → medium, width 840 → expanded.

Constructors

FilamentBreakpoints({double medium = 600, double expanded = 840})
Creates a FilamentBreakpoints with custom or default thresholds.
const

Properties

expanded double
Viewport width threshold for expanded form factor. Width ≥ expanded transitions from medium to expanded.
final
hashCode int
The hash code for this object.
no setterinherited
medium double
Viewport width threshold for medium form factor. Width ≥ medium transitions from compact to medium.
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
of(double width) FilamentFormFactor
Determines the form factor for a given viewport width.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited