FilamentLayout class
Provides layout breakpoints to descendants via InheritedWidget.
Uses the nearest FilamentLayout's breakpoints to determine the active form factor from MediaQuery.sizeOf. When no FilamentLayout ancestor exists, falls back to a default FilamentBreakpoints.
This is an InheritedWidget (not a mere data class) so that the host app can override breakpoints at the widget tree level, while still allowing package widgets to work standalone without the shell by falling back to MediaQuery when no ancestor exists.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- ProxyWidget
- InheritedWidget
- FilamentLayout
Constructors
- FilamentLayout({required FilamentBreakpoints breakpoints, required Widget child, Key? key})
-
Creates a FilamentLayout that provides breakpoints to descendants.
const
Properties
- breakpoints → FilamentBreakpoints
-
The breakpoints used to determine the active form factor.
final
- child → Widget
-
The widget below this widget in the tree.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → InheritedElement -
Inflates this configuration to a concrete instance.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
updateShouldNotify(
covariant FilamentLayout old) → bool -
Whether the framework should notify widgets that inherit from this widget.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
isCompact(
BuildContext context) → bool - Returns true if the current form factor is FilamentFormFactor.compact.
-
of(
BuildContext context) → FilamentFormFactor - Looks up the active FilamentFormFactor from the nearest FilamentLayout.